@@ -2,5 +2,5 @@ from .models import SSLContextMap, SSLContext
 
 
 class NoSSLContextMap(SSLContextMap):
-    def __geitem__(self, uri: str):
+    def __getitem__(self, uri: str):
         return None
